==> 2.5.0.zip: cloudlog/application/language/polish/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'Uwaga: musisz ustawić aktywną lokalizacje stacji.';

$lang['notice_turn_the_radio_on'] = 'Nie zrobiłeś dziś łączności; czas włączyć radio!';

$lang['general_word_important'] = 'Ważne';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Informacja';
$lang['general_word_choose_file'] = 'Wybież plik';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";

$lang['general_word_date'] = 'Data';
$lang['general_word_time'] = 'Godzina';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Data/Godzina';
$lang['general_word_none'] = 'Nic';
$lang['general_word_name'] = 'Imie';
$lang['general_word_location'] = 'Lokalizacja';
$lang['general_word_comment'] = 'Komentarz';
$lang['general_word_general'] = 'Główne';
$lang['general_word_satellite'] = 'Satelita';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Notatki';
$lang['general_word_country'] = 'Kraj';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Suma';
$lang['general_word_year'] = 'Rok';
$lang['general_word_month'] = 'Miesiąc';

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Pracowane';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Potwierdzone';
$lang['general_word_needed'] = 'Wymagane';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Nie';
$lang['general_word_yes'] = 'Tak';
$lang['general_word_method'] = 'Sposób';

$lang['general_word_sent'] = 'Wysłane';
$lang['general_word_received'] = 'Odebrane';
$lang['general_word_requested'] = 'Poproszone';
$lang['general_word_queued'] = 'Queued';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Invalid (Ignore)';
$lang['general_word_qslcard'] = 'Karta QSL';
$lang['general_word_qslcard_management'] = 'Zarządzanie kartami';
$lang['general_word_qslcards'] = 'Karty QSL';
$lang['general_word_qslcard_direct'] = 'Direct';
$lang['general_word_qslcard_bureau'] = 'Biuro';
$lang['general_word_qslcard_electronic'] = 'Electronic';
$lang['general_word_qslcard_manager'] = 'Manager';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Cards';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Edytuj QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Zaznacz QSL jako odebraną przez (Biuro)';
$lang['general_mark_qsl_rx_direct'] = 'Zaznacz QSL jako odebraną przez (Bezpośredni)';
$lang['general_mark_qsl_rx_electronic'] = 'Zaznacz QSL jako odebraną przez (Elektroniczny)';
$lang['general_mark_qsl_tx_bureau'] = 'Zaznacz QSL jako wysłaną przez (Biuro)';
$lang['general_mark_qsl_tx_direct'] = 'Zaznacz QSL jako wysłaną przez (Bezpośredni)';
$lang['general_mark_qsl_requested'] = 'Zaznacz QSL zgodnie z żądaniem';
$lang['general_mark_qsl_requested_bureau'] = 'Zaznacz QSL zgodnie z żądaniem (Biuro)';
$lang['general_mark_qsl_requested_direct'] = 'Zaznacz QSL zgodnie z żądaniem (Bezpośredni)';
$lang['general_mark_qsl_not_required'] = 'Zaznacz QSLjako niewymagane';

$lang['general_delete_qso'] = 'Usuń QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Suma odległości';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Lokalizacja stacji';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Stacja';

$lang['gen_hamradio_call'] = 'Znak';
$lang['gen_hamradio_callsign'] = 'Znak';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Modulacja';
$lang['gen_hamradio_rst_sent'] = 'Wysłany';
$lang['gen_hamradio_rst_rcvd'] = 'Odebrany\'d';
$lang['gen_hamradio_band'] = 'Pasmo';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Pasmo (RX)';
$lang['gen_hamradio_frequency'] = 'Częstotliwość';
$lang['gen_hamradio_frequency_rx'] = 'Częstotliwość (RX)';
$lang['gen_hamradio_radio'] = 'Radio';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Wymiana (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Wymiana (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Lokator';
$lang['gen_hamradio_transmit_power'] = 'Moc nadajnika (W)';
$lang['gen_hamradio_propagation_mode'] = 'Typ propagacji';

$lang['gen_hamradio_satellite_name'] = 'Nazwa satelity';
$lang['gen_hamradio_satellite_mode'] = 'modulacja satelity';

$lang['gen_hamradio_logbook'] = 'Log';

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'Strefa CQ';
$lang['gen_hamradio_itu_zone'] = 'Strefa ITU';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'Stan USA';
$lang['gen_hamradio_county_reference'] = 'Hrabstwo USA';
$lang['gen_hamradio_iota_reference'] = 'Podmiot IOTA';
$lang['gen_hamradio_sota_reference'] = 'Podmiot SOTA';
$lang['gen_hamradio_wwff_reference'] = 'Podmiot WWFF';
$lang['gen_hamradio_pota_reference'] = 'POTA Reference';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Stan';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Lokator';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operator';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then ";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then ";
$lang['gen_find_zone_part2'] = 'click here';
$lang['gen_find_zone_part3'] = ' to find it!';

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Już miałeś';
$lang['dashboard_qsos_today'] = 'QSOs Today!';
$lang['dashboard_qso_breakdown'] = 'Rozkład QSO';
$lang['dashboard_countries_breakdown'] = 'Rozkład na kraje';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'Od daty';

$lang['gen_this_qso_was_confirmed_on'] = 'Ta łączność została potwierdzona';

$lang['error_no_logbook_found'] = 'No logbooks were found. You need to define a logbook under Station Logbooks! Do it here:';

$lang['copy_to_clipboard'] = 'Copy to clipboard';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

==> 2.6.6.zip: cloudlog/application/language/polish/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'Uwaga: musisz ustawić aktywną lokalizacje stacji.';

$lang['notice_turn_the_radio_on'] = 'Nie zrobiłeś dziś łączności; czas włączyć radio!';

$lang['general_word_important'] = 'Ważne';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Informacja';
$lang['general_word_choose_file'] = 'Wybież plik';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";
$lang['general_word_count'] = "Count";
$lang['general_word_filtering_on'] = "Filtering on";
$lang['general_word_not_display'] = "Not display";
$lang['general_word_icon'] = "Icon";
$lang['general_word_never'] = "Never";

$lang['general_word_date'] = 'Data';
$lang['general_word_startdate'] = "Start Date";
$lang['general_word_enddate'] = "End Date";
$lang['general_word_time'] = 'Godzina';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Data/Godzina';
$lang['general_word_none'] = 'Nic';
$lang['general_word_name'] = 'Imie';
$lang['general_word_location'] = 'Lokalizacja';
$lang['general_word_comment'] = 'Komentarz';
$lang['general_word_general'] = 'Główne';
$lang['general_word_satellite'] = 'Satelita';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Notatki';
$lang['general_word_country'] = 'Kraj';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Suma';
$lang['general_word_year'] = 'Rok';
$lang['general_word_month'] = 'Miesiąc';
$lang['general_word_day'] = "Day";
$lang['general_word_days'] = "Days";

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Pracowane';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Potwierdzone';
$lang['general_word_confirmation'] = "Confirmation";
$lang['general_word_needed'] = 'Wymagane';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Nie';
$lang['general_word_yes'] = 'Tak';
$lang['general_word_method'] = 'Sposób';

$lang['general_word_sent'] = 'Wysłane';
$lang['general_word_received'] = 'Odebrane';
$lang['general_word_requested'] = 'Poproszone';
$lang['general_word_queued'] = 'Queued';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Invalid (Ignore)';
$lang['general_word_qslcard'] = 'Karta QSL';
$lang['general_word_qslcard_management'] = 'Zarządzanie kartami';
$lang['general_word_qslcards'] = 'Karty QSL';
$lang['general_word_qslcard_direct'] = 'Direct';
$lang['general_word_qslcard_bureau'] = 'Biuro';
$lang['general_word_qslcard_electronic'] = 'Electronic';
$lang['general_word_qslcard_manager'] = 'Manager';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Cards';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Edytuj QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Zaznacz QSL jako odebraną przez (Biuro)';
$lang['general_mark_qsl_rx_direct'] = 'Zaznacz QSL jako odebraną przez (Bezpośredni)';
$lang['general_mark_qsl_rx_electronic'] = 'Zaznacz QSL jako odebraną przez (Elektroniczny)';
$lang['general_mark_qsl_tx_bureau'] = 'Zaznacz QSL jako wysłaną przez (Biuro)';
$lang['general_mark_qsl_tx_direct'] = 'Zaznacz QSL jako wysłaną przez (Bezpośredni)';
$lang['general_mark_qsl_requested'] = 'Zaznacz QSL zgodnie z żądaniem';
$lang['general_mark_qsl_requested_bureau'] = 'Zaznacz QSL zgodnie z żądaniem (Biuro)';
$lang['general_mark_qsl_requested_direct'] = 'Zaznacz QSL zgodnie z żądaniem (Bezpośredni)';
$lang['general_mark_qsl_not_required'] = 'Zaznacz QSLjako niewymagane';

$lang['general_delete_qso'] = 'Usuń QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Suma odległości';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Lokalizacja stacji';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Stacja';

$lang['gen_hamradio_call'] = 'Znak';
$lang['gen_hamradio_callsign'] = 'Znak';
$lang['gen_hamradio_prefix'] = "Prefix";
$lang['gen_hamradio_suffix'] = "Suffix";
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Modulacja';
$lang['gen_hamradio_ant_az'] = 'Antenna Azimuth';
$lang['gen_hamradio_ant_el'] = 'Antenna Elevation';
$lang['gen_hamradio_rst_sent'] = 'Wysłany';
$lang['gen_hamradio_rst_rcvd'] = 'Odebrany\'d';
$lang['gen_hamradio_band'] = 'Pasmo';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Pasmo (RX)';
$lang['gen_hamradio_frequency'] = 'Częstotliwość';
$lang['gen_hamradio_frequency_rx'] = 'Częstotliwość (RX)';
$lang['gen_hamradio_radio'] = 'Radio';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Wymiana (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Wymiana (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Lokator';
$lang['gen_hamradio_transmit_power'] = 'Moc nadajnika (W)';
$lang['gen_hamradio_propagation_mode'] = 'Typ propagacji';

$lang['gen_hamradio_satellite_name'] = 'Nazwa satelity';
$lang['gen_hamradio_satellite_mode'] = 'modulacja satelity';

$lang['gen_hamradio_logbook'] = 'Log';
$lang['gen_hamradio_award'] = "Award";

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'Strefa CQ';
$lang['gen_hamradio_itu_zone'] = 'Strefa ITU';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'Stan USA';
$lang['gen_hamradio_county_reference'] = 'Hrabstwo USA';
$lang['gen_hamradio_iota_reference'] = 'Podmiot IOTA';
$lang['gen_hamradio_sota_reference'] = 'Podmiot SOTA';
$lang['gen_hamradio_wwff_reference'] = 'Podmiot WWFF';
$lang['gen_hamradio_pota_reference'] = 'POTA Reference';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Stan';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Lokator';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_gridsquare_show'] = "Show Locator";
$lang['gen_hamradio_latitude'] = "Latitude";
$lang['gen_hamradio_longitude'] = "Longitude";
$lang['gen_hamradio_bearing'] = "Bearing";
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operator';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then";
$lang['gen_find_zone_part2'] = "click here";
$lang['gen_find_zone_part3'] = "to find it!";

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Już miałeś';
$lang['dashboard_qsos_today'] = 'QSOs Today!';
$lang['dashboard_qso_breakdown'] = 'Rozkład QSO';
$lang['dashboard_countries_breakdown'] = 'Rozkład na kraje';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'Od daty';

$lang['gen_this_qso_was_confirmed_on'] = 'Ta łączność została potwierdzona';

$lang['error_no_logbook_found'] = 'No logbooks were found. You need to define a logbook under Station Logbooks! Do it here:';

$lang['copy_to_clipboard'] = 'Copy to clipboard';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

$lang['hams_at_no_activations_found'] = 'No upcoming activations found. Please check back later.';

$lang['datatables_language'] = "en-GB";
